discord-continued
====================

**An API wrapper for Discord interactions.**

.. image:: https://img.shields.io/pypi/dm/discord-continued.svg
    :target: https://pypi.org/project/discord-continued/
    :alt: PyPI Monthly Downloads

.. image:: https://img.shields.io/github/license/sakurazaki/discord-continued.svg
    :target: https://github.com/sakurazaki/discord-continued/blob/master/LICENSE
    :alt: License

.. image:: https://img.shields.io/pypi/pyversions/discord-continued.svg
    :target: https://pypi.org/project/discord-continued/
    :alt: PyPI pyversions

.. image:: https://img.shields.io/pypi/v/discord-continued.svg
    :target: https://pypi.org/project/discord-continued/
    :alt: PyPI pyversions

.. image:: https://discord.com/api/guilds/905226844851286048/embed.png
    :target: https://discord.gg/R2FsdNn29A
    :alt: Discord

----

The current version is Stable however it's still very unrefined and requires a lot of work and documentation.

This Bot feaures chunks from old discord.py that I have repurposed for this library, as they work extremely well, however I don't intend on just taking over from what was left. A lot of the code is new and rewritten.

Installation
============

Use this line to install the library:

.. code-block:: bash

    pip install -U discord-continued
